// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package dashboard aliases all exported identifiers in package
// "cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb".
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package dashboard

import (
	src "cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
const (
	Aggregation_ALIGN_COUNT                            = src.Aggregation_ALIGN_COUNT
	Aggregation_ALIGN_COUNT_FALSE                      = src.Aggregation_ALIGN_COUNT_FALSE
	Aggregation_ALIGN_COUNT_TRUE                       = src.Aggregation_ALIGN_COUNT_TRUE
	Aggregation_ALIGN_DELTA                            = src.Aggregation_ALIGN_DELTA
	Aggregation_ALIGN_FRACTION_TRUE                    = src.Aggregation_ALIGN_FRACTION_TRUE
	Aggregation_ALIGN_INTERPOLATE                      = src.Aggregation_ALIGN_INTERPOLATE
	Aggregation_ALIGN_MAX                              = src.Aggregation_ALIGN_MAX
	Aggregation_ALIGN_MEAN                             = src.Aggregation_ALIGN_MEAN
	Aggregation_ALIGN_MIN                              = src.Aggregation_ALIGN_MIN
	Aggregation_ALIGN_NEXT_OLDER                       = src.Aggregation_ALIGN_NEXT_OLDER
	Aggregation_ALIGN_NONE                             = src.Aggregation_ALIGN_NONE
	Aggregation_ALIGN_PERCENTILE_05                    = src.Aggregation_ALIGN_PERCENTILE_05
	Aggregation_ALIGN_PERCENTILE_50                    = src.Aggregation_ALIGN_PERCENTILE_50
	Aggregation_ALIGN_PERCENTILE_95                    = src.Aggregation_ALIGN_PERCENTILE_95
	Aggregation_ALIGN_PERCENTILE_99                    = src.Aggregation_ALIGN_PERCENTILE_99
	Aggregation_ALIGN_PERCENT_CHANGE                   = src.Aggregation_ALIGN_PERCENT_CHANGE
	Aggregation_ALIGN_RATE                             = src.Aggregation_ALIGN_RATE
	Aggregation_ALIGN_STDDEV                           = src.Aggregation_ALIGN_STDDEV
	Aggregation_ALIGN_SUM                              = src.Aggregation_ALIGN_SUM
	Aggregation_REDUCE_COUNT                           = src.Aggregation_REDUCE_COUNT
	Aggregation_REDUCE_COUNT_FALSE                     = src.Aggregation_REDUCE_COUNT_FALSE
	Aggregation_REDUCE_COUNT_TRUE                      = src.Aggregation_REDUCE_COUNT_TRUE
	Aggregation_REDUCE_FRACTION_TRUE                   = src.Aggregation_REDUCE_FRACTION_TRUE
	Aggregation_REDUCE_MAX                             = src.Aggregation_REDUCE_MAX
	Aggregation_REDUCE_MEAN                            = src.Aggregation_REDUCE_MEAN
	Aggregation_REDUCE_MIN                             = src.Aggregation_REDUCE_MIN
	Aggregation_REDUCE_NONE                            = src.Aggregation_REDUCE_NONE
	Aggregation_REDUCE_PERCENTILE_05                   = src.Aggregation_REDUCE_PERCENTILE_05
	Aggregation_REDUCE_PERCENTILE_50                   = src.Aggregation_REDUCE_PERCENTILE_50
	Aggregation_REDUCE_PERCENTILE_95                   = src.Aggregation_REDUCE_PERCENTILE_95
	Aggregation_REDUCE_PERCENTILE_99                   = src.Aggregation_REDUCE_PERCENTILE_99
	Aggregation_REDUCE_STDDEV                          = src.Aggregation_REDUCE_STDDEV
	Aggregation_REDUCE_SUM                             = src.Aggregation_REDUCE_SUM
	ChartOptions_COLOR                                 = src.ChartOptions_COLOR
	ChartOptions_MODE_UNSPECIFIED                      = src.ChartOptions_MODE_UNSPECIFIED
	ChartOptions_STATS                                 = src.ChartOptions_STATS
	ChartOptions_X_RAY                                 = src.ChartOptions_X_RAY
	DashboardFilter_FILTER_TYPE_UNSPECIFIED            = src.DashboardFilter_FILTER_TYPE_UNSPECIFIED
	DashboardFilter_GROUP                              = src.DashboardFilter_GROUP
	DashboardFilter_METRIC_LABEL                       = src.DashboardFilter_METRIC_LABEL
	DashboardFilter_RESOURCE_LABEL                     = src.DashboardFilter_RESOURCE_LABEL
	DashboardFilter_SYSTEM_METADATA_LABEL              = src.DashboardFilter_SYSTEM_METADATA_LABEL
	DashboardFilter_USER_METADATA_LABEL                = src.DashboardFilter_USER_METADATA_LABEL
	PickTimeSeriesFilter_BOTTOM                        = src.PickTimeSeriesFilter_BOTTOM
	PickTimeSeriesFilter_DIRECTION_UNSPECIFIED         = src.PickTimeSeriesFilter_DIRECTION_UNSPECIFIED
	PickTimeSeriesFilter_METHOD_LATEST                 = src.PickTimeSeriesFilter_METHOD_LATEST
	PickTimeSeriesFilter_METHOD_MAX                    = src.PickTimeSeriesFilter_METHOD_MAX
	PickTimeSeriesFilter_METHOD_MEAN                   = src.PickTimeSeriesFilter_METHOD_MEAN
	PickTimeSeriesFilter_METHOD_MIN                    = src.PickTimeSeriesFilter_METHOD_MIN
	PickTimeSeriesFilter_METHOD_SUM                    = src.PickTimeSeriesFilter_METHOD_SUM
	PickTimeSeriesFilter_METHOD_UNSPECIFIED            = src.PickTimeSeriesFilter_METHOD_UNSPECIFIED
	PickTimeSeriesFilter_TOP                           = src.PickTimeSeriesFilter_TOP
	SparkChartType_SPARK_BAR                           = src.SparkChartType_SPARK_BAR
	SparkChartType_SPARK_CHART_TYPE_UNSPECIFIED        = src.SparkChartType_SPARK_CHART_TYPE_UNSPECIFIED
	SparkChartType_SPARK_LINE                          = src.SparkChartType_SPARK_LINE
	StatisticalTimeSeriesFilter_METHOD_CLUSTER_OUTLIER = src.StatisticalTimeSeriesFilter_METHOD_CLUSTER_OUTLIER
	StatisticalTimeSeriesFilter_METHOD_UNSPECIFIED     = src.StatisticalTimeSeriesFilter_METHOD_UNSPECIFIED
	Text_FORMAT_UNSPECIFIED                            = src.Text_FORMAT_UNSPECIFIED
	Text_MARKDOWN                                      = src.Text_MARKDOWN
	Text_RAW                                           = src.Text_RAW
	Threshold_ABOVE                                    = src.Threshold_ABOVE
	Threshold_BELOW                                    = src.Threshold_BELOW
	Threshold_COLOR_UNSPECIFIED                        = src.Threshold_COLOR_UNSPECIFIED
	Threshold_DIRECTION_UNSPECIFIED                    = src.Threshold_DIRECTION_UNSPECIFIED
	Threshold_RED                                      = src.Threshold_RED
	Threshold_TARGET_AXIS_UNSPECIFIED                  = src.Threshold_TARGET_AXIS_UNSPECIFIED
	Threshold_Y1                                       = src.Threshold_Y1
	Threshold_Y2                                       = src.Threshold_Y2
	Threshold_YELLOW                                   = src.Threshold_YELLOW
	XyChart_Axis_LINEAR                                = src.XyChart_Axis_LINEAR
	XyChart_Axis_LOG10                                 = src.XyChart_Axis_LOG10
	XyChart_Axis_SCALE_UNSPECIFIED                     = src.XyChart_Axis_SCALE_UNSPECIFIED
	XyChart_DataSet_HEATMAP                            = src.XyChart_DataSet_HEATMAP
	XyChart_DataSet_LINE                               = src.XyChart_DataSet_LINE
	XyChart_DataSet_PLOT_TYPE_UNSPECIFIED              = src.XyChart_DataSet_PLOT_TYPE_UNSPECIFIED
	XyChart_DataSet_STACKED_AREA                       = src.XyChart_DataSet_STACKED_AREA
	XyChart_DataSet_STACKED_BAR                        = src.XyChart_DataSet_STACKED_BAR
	XyChart_DataSet_TARGET_AXIS_UNSPECIFIED            = src.XyChart_DataSet_TARGET_AXIS_UNSPECIFIED
	XyChart_DataSet_Y1                                 = src.XyChart_DataSet_Y1
	XyChart_DataSet_Y2                                 = src.XyChart_DataSet_Y2
)

// Deprecated: Please use vars in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
var (
	Aggregation_Aligner_name                                        = src.Aggregation_Aligner_name
	Aggregation_Aligner_value                                       = src.Aggregation_Aligner_value
	Aggregation_Reducer_name                                        = src.Aggregation_Reducer_name
	Aggregation_Reducer_value                                       = src.Aggregation_Reducer_value
	ChartOptions_Mode_name                                          = src.ChartOptions_Mode_name
	ChartOptions_Mode_value                                         = src.ChartOptions_Mode_value
	DashboardFilter_FilterType_name                                 = src.DashboardFilter_FilterType_name
	DashboardFilter_FilterType_value                                = src.DashboardFilter_FilterType_value
	File_google_monitoring_dashboard_v1_alertchart_proto            = src.File_google_monitoring_dashboard_v1_alertchart_proto
	File_google_monitoring_dashboard_v1_collapsible_group_proto     = src.File_google_monitoring_dashboard_v1_collapsible_group_proto
	File_google_monitoring_dashboard_v1_common_proto                = src.File_google_monitoring_dashboard_v1_common_proto
	File_google_monitoring_dashboard_v1_dashboard_filter_proto      = src.File_google_monitoring_dashboard_v1_dashboard_filter_proto
	File_google_monitoring_dashboard_v1_dashboard_proto             = src.File_google_monitoring_dashboard_v1_dashboard_proto
	File_google_monitoring_dashboard_v1_dashboards_service_proto    = src.File_google_monitoring_dashboard_v1_dashboards_service_proto
	File_google_monitoring_dashboard_v1_drilldowns_proto            = src.File_google_monitoring_dashboard_v1_drilldowns_proto
	File_google_monitoring_dashboard_v1_layouts_proto               = src.File_google_monitoring_dashboard_v1_layouts_proto
	File_google_monitoring_dashboard_v1_logs_panel_proto            = src.File_google_monitoring_dashboard_v1_logs_panel_proto
	File_google_monitoring_dashboard_v1_metrics_proto               = src.File_google_monitoring_dashboard_v1_metrics_proto
	File_google_monitoring_dashboard_v1_scorecard_proto             = src.File_google_monitoring_dashboard_v1_scorecard_proto
	File_google_monitoring_dashboard_v1_service_proto               = src.File_google_monitoring_dashboard_v1_service_proto
	File_google_monitoring_dashboard_v1_table_display_options_proto = src.File_google_monitoring_dashboard_v1_table_display_options_proto
	File_google_monitoring_dashboard_v1_table_proto                 = src.File_google_monitoring_dashboard_v1_table_proto
	File_google_monitoring_dashboard_v1_text_proto                  = src.File_google_monitoring_dashboard_v1_text_proto
	File_google_monitoring_dashboard_v1_widget_proto                = src.File_google_monitoring_dashboard_v1_widget_proto
	File_google_monitoring_dashboard_v1_xychart_proto               = src.File_google_monitoring_dashboard_v1_xychart_proto
	PickTimeSeriesFilter_Direction_name                             = src.PickTimeSeriesFilter_Direction_name
	PickTimeSeriesFilter_Direction_value                            = src.PickTimeSeriesFilter_Direction_value
	PickTimeSeriesFilter_Method_name                                = src.PickTimeSeriesFilter_Method_name
	PickTimeSeriesFilter_Method_value                               = src.PickTimeSeriesFilter_Method_value
	SparkChartType_name                                             = src.SparkChartType_name
	SparkChartType_value                                            = src.SparkChartType_value
	StatisticalTimeSeriesFilter_Method_name                         = src.StatisticalTimeSeriesFilter_Method_name
	StatisticalTimeSeriesFilter_Method_value                        = src.StatisticalTimeSeriesFilter_Method_value
	Text_Format_name                                                = src.Text_Format_name
	Text_Format_value                                               = src.Text_Format_value
	Threshold_Color_name                                            = src.Threshold_Color_name
	Threshold_Color_value                                           = src.Threshold_Color_value
	Threshold_Direction_name                                        = src.Threshold_Direction_name
	Threshold_Direction_value                                       = src.Threshold_Direction_value
	Threshold_TargetAxis_name                                       = src.Threshold_TargetAxis_name
	Threshold_TargetAxis_value                                      = src.Threshold_TargetAxis_value
	XyChart_Axis_Scale_name                                         = src.XyChart_Axis_Scale_name
	XyChart_Axis_Scale_value                                        = src.XyChart_Axis_Scale_value
	XyChart_DataSet_PlotType_name                                   = src.XyChart_DataSet_PlotType_name
	XyChart_DataSet_PlotType_value                                  = src.XyChart_DataSet_PlotType_value
	XyChart_DataSet_TargetAxis_name                                 = src.XyChart_DataSet_TargetAxis_name
	XyChart_DataSet_TargetAxis_value                                = src.XyChart_DataSet_TargetAxis_value
)

// Describes how to combine multiple time series to provide a different view
// of the data. Aggregation of time series is done in two steps. First, each
// time series in the set is _aligned_ to the same time interval boundaries,
// then the set of time series is optionally _reduced_ in number. Alignment
// consists of applying the `per_series_aligner` operation to each time series
// after its data has been divided into regular `alignment_period` time
// intervals. This process takes _all_ of the data points in an alignment
// period, applies a mathematical transformation such as averaging, minimum,
// maximum, delta, etc., and converts them into a single data point per period.
// Reduction is when the aligned and transformed time series can optionally be
// combined, reducing the number of time series through similar mathematical
// transformations. Reduction involves applying a `cross_series_reducer` to all
// the time series, optionally sorting the time series into subsets with
// `group_by_fields`, and applying the reducer to each subset. The raw time
// series data can contain a huge amount of information from multiple sources.
// Alignment and reduction transforms this mass of data into a more manageable
// and representative collection of data, for example "the 95% latency across
// the average of all tasks in a cluster". This representative data can be more
// easily graphed and comprehended, and the individual time series data is
// still available for later drilldown. For more details, see [Filtering and
// aggregation](https://cloud.google.com/monitoring/api/v3/aggregation).
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type Aggregation = src.Aggregation

// The `Aligner` specifies the operation that will be applied to the data
// points in each alignment period in a time series. Except for `ALIGN_NONE`,
// which specifies that no operation be applied, each alignment operation
// replaces the set of data values in each alignment period with a single
// value: the result of applying the operation to the data values. An aligned
// time series has a single data value at the end of each `alignment_period`.
// An alignment operation can change the data type of the values, too. For
// example, if you apply a counting operation to boolean values, the data
// `value_type` in the original time series is `BOOLEAN`, but the `value_type`
// in the aligned result is `INT64`.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type Aggregation_Aligner = src.Aggregation_Aligner

// A Reducer operation describes how to aggregate data points from multiple
// time series into a single time series, where the value of each data point in
// the resulting series is a function of all the already aligned values in the
// input time series.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type Aggregation_Reducer = src.Aggregation_Reducer

// A chart that displays alert policy data.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type AlertChart = src.AlertChart

// Options to control visual rendering of a chart.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type ChartOptions = src.ChartOptions

// Chart mode options.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type ChartOptions_Mode = src.ChartOptions_Mode

// A widget that groups the other widgets. All widgets that are within the
// area spanned by the grouping widget are considered member widgets.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type CollapsibleGroup = src.CollapsibleGroup

// A simplified layout that divides the available space into vertical columns
// and arranges a set of widgets vertically in each column.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type ColumnLayout = src.ColumnLayout

// Defines the layout properties and content for a column.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type ColumnLayout_Column = src.ColumnLayout_Column

// The `CreateDashboard` request.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type CreateDashboardRequest = src.CreateDashboardRequest

// A Google Stackdriver dashboard. Dashboards define the content and layout of
// pages in the Stackdriver web application.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type Dashboard = src.Dashboard

// A filter to reduce the amount of data charted in relevant widgets.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type DashboardFilter = src.DashboardFilter

// The type for the dashboard filter
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type DashboardFilter_FilterType = src.DashboardFilter_FilterType
type DashboardFilter_StringValue = src.DashboardFilter_StringValue
type Dashboard_ColumnLayout = src.Dashboard_ColumnLayout
type Dashboard_GridLayout = src.Dashboard_GridLayout
type Dashboard_MosaicLayout = src.Dashboard_MosaicLayout
type Dashboard_RowLayout = src.Dashboard_RowLayout

// DashboardsServiceClient is the client API for DashboardsService service.
// For semantics around ctx use and closing/ending streaming RPCs, please refer
// to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type DashboardsServiceClient = src.DashboardsServiceClient

// DashboardsServiceServer is the server API for DashboardsService service.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type DashboardsServiceServer = src.DashboardsServiceServer

// The `DeleteDashboard` request.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type DeleteDashboardRequest = src.DeleteDashboardRequest

// The `GetDashboard` request.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type GetDashboardRequest = src.GetDashboardRequest

// A basic layout divides the available space into vertical columns of equal
// width and arranges a list of widgets using a row-first strategy.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type GridLayout = src.GridLayout

// The `ListDashboards` request.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type ListDashboardsRequest = src.ListDashboardsRequest

// The `ListDashboards` request.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type ListDashboardsResponse = src.ListDashboardsResponse

// A widget that displays a stream of log.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type LogsPanel = src.LogsPanel

// A mosaic layout divides the available space into a grid of blocks, and
// overlays the grid with tiles. Unlike `GridLayout`, tiles may span multiple
// grid blocks and can be placed at arbitrary locations in the grid.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type MosaicLayout = src.MosaicLayout

// A single tile in the mosaic. The placement and size of the tile are
// configurable.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type MosaicLayout_Tile = src.MosaicLayout_Tile

// Describes a ranking-based time series filter. Each input time series is
// ranked with an aligner. The filter will allow up to `num_time_series` time
// series to pass through it, selecting them based on the relative ranking. For
// example, if `ranking_method` is `METHOD_MEAN`,`direction` is `BOTTOM`, and
// `num_time_series` is 3, then the 3 times series with the lowest mean values
// will pass through the filter.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type PickTimeSeriesFilter = src.PickTimeSeriesFilter

// Describes the ranking directions.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type PickTimeSeriesFilter_Direction = src.PickTimeSeriesFilter_Direction

// The value reducers that can be applied to a `PickTimeSeriesFilter`.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type PickTimeSeriesFilter_Method = src.PickTimeSeriesFilter_Method

// A simplified layout that divides the available space into rows and arranges
// a set of widgets horizontally in each row.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type RowLayout = src.RowLayout

// Defines the layout properties and content for a row.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type RowLayout_Row = src.RowLayout_Row

// A widget showing the latest value of a metric, and how this value relates
// to one or more thresholds.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type Scorecard = src.Scorecard

// A gauge chart shows where the current value sits within a pre-defined
// range. The upper and lower bounds should define the possible range of values
// for the scorecard's query (inclusive).
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type Scorecard_GaugeView = src.Scorecard_GaugeView
type Scorecard_GaugeView_ = src.Scorecard_GaugeView_

// A sparkChart is a small chart suitable for inclusion in a table-cell or
// inline in text. This message contains the configuration for a sparkChart to
// show up on a Scorecard, showing recent trends of the scorecard's timeseries.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type Scorecard_SparkChartView = src.Scorecard_SparkChartView
type Scorecard_SparkChartView_ = src.Scorecard_SparkChartView_

// Defines the possible types of spark chart supported by the `Scorecard`.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type SparkChartType = src.SparkChartType

// A filter that ranks streams based on their statistical relation to other
// streams in a request. Note: This field is deprecated and completely ignored
// by the API.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type StatisticalTimeSeriesFilter = src.StatisticalTimeSeriesFilter

// The filter methods that can be applied to a stream.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type StatisticalTimeSeriesFilter_Method = src.StatisticalTimeSeriesFilter_Method

// Table display options that can be reused.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type TableDisplayOptions = src.TableDisplayOptions

// A widget that displays textual content.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type Text = src.Text

// The format type of the text content.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type Text_Format = src.Text_Format

// Defines a threshold for categorizing time series values.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type Threshold = src.Threshold

// The color suggests an interpretation to the viewer when actual values cross
// the threshold. Comments on each color provide UX guidance on how users can
// be expected to interpret a given state color.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type Threshold_Color = src.Threshold_Color

// Whether the threshold is considered crossed by an actual value above or
// below its threshold value.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type Threshold_Direction = src.Threshold_Direction

// An axis identifier.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type Threshold_TargetAxis = src.Threshold_TargetAxis

// A filter that defines a subset of time series data that is displayed in a
// widget. Time series data is fetched using the
// [`ListTimeSeries`](https://cloud.google.com/monitoring/api/ref_v3/rest/v3/projects.timeSeries/list)
// method.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type TimeSeriesFilter = src.TimeSeriesFilter

// A pair of time series filters that define a ratio computation. The output
// time series is the pair-wise division of each aligned element from the
// numerator and denominator time series.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type TimeSeriesFilterRatio = src.TimeSeriesFilterRatio
type TimeSeriesFilterRatio_PickTimeSeriesFilter = src.TimeSeriesFilterRatio_PickTimeSeriesFilter

// Describes a query to build the numerator or denominator of a
// TimeSeriesFilterRatio.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type TimeSeriesFilterRatio_RatioPart = src.TimeSeriesFilterRatio_RatioPart
type TimeSeriesFilterRatio_StatisticalTimeSeriesFilter = src.TimeSeriesFilterRatio_StatisticalTimeSeriesFilter
type TimeSeriesFilter_PickTimeSeriesFilter = src.TimeSeriesFilter_PickTimeSeriesFilter
type TimeSeriesFilter_StatisticalTimeSeriesFilter = src.TimeSeriesFilter_StatisticalTimeSeriesFilter

// TimeSeriesQuery collects the set of supported methods for querying time
// series data from the Stackdriver metrics API.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type TimeSeriesQuery = src.TimeSeriesQuery
type TimeSeriesQuery_TimeSeriesFilter = src.TimeSeriesQuery_TimeSeriesFilter
type TimeSeriesQuery_TimeSeriesFilterRatio = src.TimeSeriesQuery_TimeSeriesFilterRatio
type TimeSeriesQuery_TimeSeriesQueryLanguage = src.TimeSeriesQuery_TimeSeriesQueryLanguage

// A table that displays time series data.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type TimeSeriesTable = src.TimeSeriesTable

// Groups a time series query definition with table options.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type TimeSeriesTable_TableDataSet = src.TimeSeriesTable_TableDataSet

// UnimplementedDashboardsServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type UnimplementedDashboardsServiceServer = src.UnimplementedDashboardsServiceServer

// The `UpdateDashboard` request.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type UpdateDashboardRequest = src.UpdateDashboardRequest

// Widget contains a single dashboard component and configuration of how to
// present the component in the dashboard.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type Widget = src.Widget
type Widget_AlertChart = src.Widget_AlertChart
type Widget_Blank = src.Widget_Blank
type Widget_CollapsibleGroup = src.Widget_CollapsibleGroup
type Widget_LogsPanel = src.Widget_LogsPanel
type Widget_Scorecard = src.Widget_Scorecard
type Widget_Text = src.Widget_Text
type Widget_TimeSeriesTable = src.Widget_TimeSeriesTable
type Widget_XyChart = src.Widget_XyChart

// A chart that displays data on a 2D (X and Y axes) plane.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type XyChart = src.XyChart

// A chart axis.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type XyChart_Axis = src.XyChart_Axis

// Types of scales used in axes.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type XyChart_Axis_Scale = src.XyChart_Axis_Scale

// Groups a time series query definition with charting options.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type XyChart_DataSet = src.XyChart_DataSet

// The types of plotting strategies for data sets.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type XyChart_DataSet_PlotType = src.XyChart_DataSet_PlotType

// An axis identifier.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
type XyChart_DataSet_TargetAxis = src.XyChart_DataSet_TargetAxis

// Deprecated: Please use funcs in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
func NewDashboardsServiceClient(cc grpc.ClientConnInterface) DashboardsServiceClient {
	return src.NewDashboardsServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/monitoring/dashboard/apiv1/dashboardpb
func RegisterDashboardsServiceServer(s *grpc.Server, srv DashboardsServiceServer) {
	src.RegisterDashboardsServiceServer(s, srv)
}
